@@ -16,8 +16,10 @@ def index(request):
         modulename, attr = m.rsplit('.', 1)
         module = import_module(modulename)
         name = getattr(module,attr)().name
-        value = getattr(module,attr)().get_text()
-        bb.append({'name':name, 'value':value})
+        text = getattr(module,attr)().get_text()
+        value = getattr(module,attr)().get_val()
+        warning = getattr(module,attr)().warning()
+        bb.append({'name':name, 'value':value, 'text':text, 'warning':warning})
     
     return render_to_response('bigbrother/index.html', {'bb': bb}, context_instance=RequestContext(request)) 
 
@@ -29,9 +31,11 @@ def graph(request, slug):
     else: month = q
     if q.count() >= 365: year = q[q.count()-365:]
     else: year = q
-    lastdow = week[week.count()-1].added
-    lastdom = month[month.count()-1].added
-    lastdoy = year[year.count()-1].added
+    
+    if q:
+        lastdow = week[week.count()-1].added
+        lastdom = month[month.count()-1].added
+        lastdoy = year[year.count()-1].added
     return render_to_response('bigbrother/graph.html', locals(), context_instance=RequestContext(request))
 
 def update(request):
